<!-- Branding -->
<p align="center">
  <img src="https://imgur.com/L2IZ2MH.png" width="120" alt="clickgen" />
  <br />
  <img src="https://i.imgur.com/TeItlMh.png" width="200" />
</p>

<p align="center">
  X11 & Windows Cursor API 👷
</p>

<!-- Badges -->
<p align="center">
  <a href="https://github.com/KaizIqbal/clickgen/actions?query=workflow%3Abuild">
    <img alt="GitHub Action Build" src="https://github.com/KaizIqbal/clickgen/workflows/build/badge.svg?branch=master&event=push" />
  </a>

  <a href="https://badge.fury.io/py/clickgen">
    <img src="https://badge.fury.io/py/clickgen.svg" alt="PyPI version" height="20">
  </a>

  <a href="https://www.codefactor.io/repository/github/kaiziqbal/clickgen">
    <img src="https://www.codefactor.io/repository/github/kaiziqbal/clickgen/badge" alt="CodeFactor" />
  </a>
</p>
